@@ -29,20 +29,20 @@ G_BEGIN_DECLS
 
 typedef struct _GIrParser GIrParser;
 
-GIrParser *g_ir_parser_new          (void);
-void       g_ir_parser_free         (GIrParser          *parser);
-void       g_ir_parser_set_includes (GIrParser          *parser,
-				     const gchar *const *includes);
+GIrParser *_g_ir_parser_new          (void);
+void       _g_ir_parser_free         (GIrParser          *parser);
+void       _g_ir_parser_set_includes (GIrParser          *parser,
+				      const gchar *const *includes);
 
-GIrModule *g_ir_parser_parse_string (GIrParser    *parser,
-				     const gchar  *namespace,
-				     const gchar  *filename,
-				     const gchar  *buffer,
-				     gssize        length,
-				     GError      **error);
-GIrModule *g_ir_parser_parse_file   (GIrParser    *parser,
-				     const gchar  *filename,
-				     GError      **error);
+GIrModule *_g_ir_parser_parse_string (GIrParser    *parser,
+				      const gchar  *namespace,
+				      const gchar  *filename,
+				      const gchar  *buffer,
+				      gssize        length,
+				      GError      **error);
+GIrModule *_g_ir_parser_parse_file   (GIrParser    *parser,
+				      const gchar  *filename,
+				      GError      **error);
 
 G_END_DECLS
 
