@@ -704,7 +704,8 @@ write_value_info (const gchar *namespace,
 		  Xml         *file)
 {
   const gchar *name;
-  glong value;
+  gint64 value;
+  gchar *value_str;
   gboolean deprecated;
 
   name = g_base_info_get_name ((GIBaseInfo *)info);
@@ -712,7 +713,9 @@ write_value_info (const gchar *namespace,
   deprecated = g_base_info_is_deprecated ((GIBaseInfo *)info);
 
   xml_start_element (file, "member");
-  xml_printf (file, " name=\"%s\" value=\"%ld\"", name, value);
+  value_str = g_strdup_printf ("%" G_GINT64_FORMAT, value);
+  xml_printf (file, " name=\"%s\" value=\"%s\"", name, value_str);
+  g_free (value_str);
 
   if (deprecated)
     xml_printf (file, " deprecated=\"1\"");
@@ -1349,6 +1352,7 @@ gir_writer_write (const char *filename,
       const gchar *c_prefix;
       const char *ns = namespace;
       const char *version;
+      gint n_infos;
 
       version = g_irepository_get_version (repository, ns);
 
@@ -1361,7 +1365,8 @@ gir_writer_write (const char *filename,
       if (c_prefix)
         xml_printf (xml, " c:prefix=\"%s\"", c_prefix);
 
-      for (j = 0; j < g_irepository_get_n_infos (repository, ns); j++)
+      n_infos = g_irepository_get_n_infos (repository, ns);
+      for (j = 0; j < n_infos; j++)
 	{
 	  GIBaseInfo *info = g_irepository_get_info (repository, ns, j);
 	  switch (g_base_info_get_type (info))
