@@ -25,9 +25,6 @@ import re
 from . import message
 from .odict import odict
 
-# All gtk-doc comments needs to start with this:
-_COMMENT_HEADER = '*\n '
-
 # Tags - annotations applyed to comment blocks
 TAG_VFUNC = 'virtual'
 TAG_SINCE = 'since'
@@ -57,6 +54,8 @@ OPT_SCOPE = 'scope'
 OPT_TRANSFER = 'transfer'
 OPT_TYPE = 'type'
 OPT_SKIP = 'skip'
+OPT_CONSTRUCTOR = 'constructor'
+OPT_METHOD = 'method'
 
 ALL_OPTIONS = [
     OPT_ALLOW_NONE,
@@ -73,7 +72,9 @@ ALL_OPTIONS = [
     OPT_SCOPE,
     OPT_TRANSFER,
     OPT_TYPE,
-    OPT_SKIP]
+    OPT_SKIP,
+    OPT_CONSTRUCTOR,
+    OPT_METHOD]
 
 # Array options - array specific annotations
 OPT_ARRAY_FIXED_SIZE = 'fixed-size'
@@ -124,7 +125,10 @@ class DocBlock(object):
         if self.options:
             options += ' '
             options += ' '.join('(%s)' % o for o in self.options)
-        lines = [self.name + ':' + options]
+        lines = [self.name]
+        if 'SECTION' not in self.name:
+            lines[0] += ':'
+        lines[0] += options
         tags = []
         for name, tag in self.tags.iteritems():
             if name in self.params:
@@ -329,6 +333,10 @@ class DocTag(object):
             elif option == OPT_TYPE:
                 self._validate_option('type', value, required=True,
                                       n_params=1)
+            elif option == OPT_CONSTRUCTOR:
+                self._validate_option('constructor', value, n_params=0)
+            elif option == OPT_METHOD:
+                self._validate_option('method', value, n_params=0)
             else:
                 message.warn('invalid annotation option: %s' % (option, ),
                              self.position)
@@ -405,6 +413,7 @@ class DocOption(object):
 
 
 class AnnotationParser(object):
+    COMMENT_HEADER_RE = re.compile(r'^\*[ \t]*\n ')
     WHITESPACE_RE = re.compile(r'^\s*$')
     ASCII_TEXT_RE = re.compile(r'\s*[A-Za-z]+')
     OPTION_RE = re.compile(r'\([A-Za-z]+[^(]*\)')
@@ -434,9 +443,9 @@ class AnnotationParser(object):
         #
         comment, filename, lineno = cmt
         comment = comment.lstrip()
-        if not comment.startswith(_COMMENT_HEADER):
+        if not self.COMMENT_HEADER_RE.search(comment):
             return
-        comment = comment[len(_COMMENT_HEADER):]
+        comment = self.COMMENT_HEADER_RE.sub('', comment, count=1)
         comment = comment.strip()
         if not comment.startswith('* '):
             return
@@ -449,8 +458,11 @@ class AnnotationParser(object):
         block_header = block_header.strip()
         cpos = block_header.find(': ')
         block_name = block_header
-        if cpos:
-            block_name = block_name[:cpos]
+        raw_name = block_header
+        if cpos != -1:
+            block_name = block_name[:cpos].strip()
+        if block_name.endswith(':'):
+            block_name = block_name[:-1]
         block = DocBlock(block_name)
         block.set_position(message.Position(filename, lineno))
 
@@ -508,7 +520,11 @@ class AnnotationParser(object):
                     argname = TAG_RETURNS
                 tag = DocTag(block, argname)
                 tag.set_position(block.position.offset(lineno))
-                second_colon_index = line.rfind(':')
+                line_after_first_colon_space = line[first_colonspace_index + 2:]
+                second_colon_index = line_after_first_colon_space.find(':')
+                if second_colon_index >= 0:
+                    second_colon_index += first_colonspace_index + 2
+                    assert line[second_colon_index] == ':'
                 found_options = False
                 if second_colon_index > first_colonspace_index:
                     value_line = \
