@@ -31,7 +31,8 @@ from .annotationparser import (OPT_ALLOW_NONE, OPT_ARRAY, OPT_ATTRIBUTE,
                                OPT_OUT_CALLER_ALLOCATES, OPT_OUT_CALLEE_ALLOCATES,
                                OPT_TYPE, OPT_CLOSURE, OPT_DESTROY, OPT_TRANSFER, OPT_SKIP,
                                OPT_FOREIGN, OPT_ARRAY_FIXED_SIZE,
-                               OPT_ARRAY_LENGTH, OPT_ARRAY_ZERO_TERMINATED)
+                               OPT_ARRAY_LENGTH, OPT_ARRAY_ZERO_TERMINATED,
+                               OPT_CONSTRUCTOR, OPT_METHOD)
 from .annotationparser import AnnotationParser
 from .transformer import TransformerException
 from .utils import to_underscores, to_underscores_noprefix
@@ -216,6 +217,11 @@ usage is void (*_gtk_reserved1)(void);"""
             block = self._get_block(node)
             for field in node.fields:
                 self._apply_annotations_field(node, block, field)
+            name = self._get_annotation_name(node)
+            section_name = 'SECTION:' + name.lower()
+            block = self._blocks.get(section_name)
+            if block:
+                node.doc = block.comment
         if isinstance(node, (ast.Class, ast.Interface)):
             for prop in node.properties:
                 self._apply_annotations_property(node, prop)
@@ -325,8 +331,10 @@ usage is void (*_gtk_reserved1)(void);"""
             # We're assuming here that Foo* with an (array) annotation
             # and no (element-type) means array of Foo
             element_type_node = node.type.clone()
-            # Explicitly erase ctype since it's no longer valid
-            element_type_node.ctype = None
+            # The element's ctype is the array's dereferenced
+            if element_type_node.ctype is not None and \
+                    element_type_node.ctype.endswith('*'):
+                element_type_node.ctype = element_type_node.ctype[:-1]
 
         if isinstance(node.type, ast.Array):
             array_type = node.type.array_type
@@ -501,6 +509,7 @@ usage is void (*_gtk_reserved1)(void);"""
             if subtype in (None, ''):
                 if node.type.target_giname and node.type.ctype:
                     target = self._transformer.lookup_giname(node.type.target_giname)
+                    target = self._transformer.resolve_aliases(target)
                     has_double_indirection = '**' in node.type.ctype
                     is_structure_or_union = isinstance(target, (ast.Record, ast.Union))
                     caller_allocates = (not has_double_indirection and is_structure_or_union)
@@ -571,6 +580,12 @@ usage is void (*_gtk_reserved1)(void);"""
         if OPT_FOREIGN in block.options:
             node.foreign = True
 
+        if OPT_CONSTRUCTOR in block.options and isinstance(node, ast.Function):
+            node.is_constructor = True
+
+        if OPT_METHOD in block.options:
+            node.is_method = True
+
     def _apply_annotations_alias(self, node, chain):
         block = self._get_block(node)
         self._apply_annotations_annotated(node, block)
@@ -882,9 +897,11 @@ method or constructor of some type."""
             return
         (ns, subsymbol) = self._transformer.split_csymbol(func.symbol)
         assert ns == self._namespace
-        if self._pair_constructor(func, subsymbol):
+        if self._is_constructor(func, subsymbol):
+            self._set_up_constructor(func, subsymbol)
             return
-        elif self._pair_method(func, subsymbol):
+        elif self._is_method(func, subsymbol):
+            self._setup_method(func, subsymbol)
             return
         elif self._pair_static_method(func, subsymbol):
             return
@@ -894,16 +911,27 @@ method or constructor of some type."""
         name = typeval.get_giname()
         return to_underscores_noprefix(name).lower()
 
-    def _pair_method(self, func, subsymbol):
+    def _is_method(self, func, subsymbol):
         if not func.parameters:
+            if func.is_method:
+                message.warn_node(func,
+                    '%s: Methods must have parameters' % (func.symbol, ))
             return False
         first = func.parameters[0]
         target = self._transformer.lookup_typenode(first.type)
         if not isinstance(target, (ast.Class, ast.Interface,
                                    ast.Record, ast.Union,
                                    ast.Boxed)):
+            if func.is_method:
+                message.warn_node(func,
+                    '%s: Methods must have a pointer as their first '
+                    'parameter' % (func.symbol, ))
             return False
         if target.namespace != self._namespace:
+            if func.is_method:
+                message.warn_node(func,
+                    '%s: Methods must belong to the same namespace as the '
+                    'class they belong to' % (func.symbol, ))
             return False
 
         # A quick hack here...in the future we should catch C signature/GI signature
@@ -911,6 +939,28 @@ method or constructor of some type."""
         if first.type.ctype is not None and first.type.ctype.count('*') != 1:
             return False
 
+        if not func.is_method:
+            uscored_prefix = self._get_uscored_prefix(func, subsymbol)
+            if not subsymbol.startswith(uscored_prefix):
+                return False
+
+        return True
+
+    def _setup_method(self, func, subsymbol):
+        uscored_prefix = self._get_uscored_prefix(func, subsymbol)
+        target = self._transformer.lookup_typenode(func.parameters[0].type)
+
+        func.instance_parameter = func.parameters.pop(0)
+        self._namespace.float(func)
+
+        if not func.is_method:
+            subsym_idx = func.symbol.find(subsymbol)
+            func.name = func.symbol[(subsym_idx + len(uscored_prefix) + 1):]
+            func.is_method = True
+
+        target.methods.append(func)
+
+    def _get_uscored_prefix(self, func, subsymbol):
         # Here we check both the c_symbol_prefix and (if that fails),
         # attempt to do a default uscoring of the type.  The reason we
         # look at a default underscore transformation is for
@@ -919,21 +969,16 @@ method or constructor of some type."""
         # "gdk_window".  Possibly need an annotation to override this.
         prefix_matches = False
         uscored_prefix = None
+        first_arg = func.parameters[0]
+        target = self._transformer.lookup_typenode(first_arg.type)
         if hasattr(target, 'c_symbol_prefix') and target.c_symbol_prefix is not None:
             prefix_matches = subsymbol.startswith(target.c_symbol_prefix)
             if prefix_matches:
                 uscored_prefix = target.c_symbol_prefix
         if not prefix_matches:
-            uscored_prefix = self._uscored_identifier_for_type(first.type)
-            if not subsymbol.startswith(uscored_prefix):
-                return False
-        func.instance_parameter = func.parameters.pop(0)
-        subsym_idx = func.symbol.find(subsymbol)
-        self._namespace.float(func)
-        func.name = func.symbol[(subsym_idx + len(uscored_prefix) + 1):]
-        target.methods.append(func)
-        func.is_method = True
-        return True
+            uscored_prefix = self._uscored_identifier_for_type(first_arg.type)
+
+        return uscored_prefix
 
     def _pair_static_method(self, func, subsymbol):
         split = self._split_uscored_by_type(subsymbol)
@@ -954,22 +999,69 @@ method or constructor of some type."""
         func.name = funcname
         node.static_methods.append(func)
 
-    def _pair_constructor(self, func, subsymbol):
-        if not (func.symbol.find('_new_') >= 0 or func.symbol.endswith('_new')):
+    def _set_up_constructor(self, func, subsymbol):
+        self._namespace.float(func)
+
+        func.name = self._get_constructor_name(func, subsymbol)
+
+        origin_node = self._get_constructor_class(func, subsymbol)
+        origin_node.constructors.append(func)
+
+        func.is_constructor = True
+
+        # Constructors have default return semantics
+        if not func.retval.transfer:
+            func.retval.transfer = self._get_transfer_default_return(func,
+                    func.retval)
+
+    def _get_constructor_class(self, func, subsymbol):
+        origin_node = None
+        split = self._split_uscored_by_type(subsymbol)
+        if split is None:
+            if func.is_constructor:
+                origin_node = self._transformer.lookup_typenode(func.retval.type)
+        else:
+            origin_node, _ = split
+
+        return origin_node
+
+    def _get_constructor_name(self, func, subsymbol):
+        name = None
+        split = self._split_uscored_by_type(subsymbol)
+        if split is None:
+            if func.is_constructor:
+                name = func.name
+        else:
+            _, name = split
+
+        return name
+
+    def _is_constructor(self, func, subsymbol):
+        if False and func.symbol == 'regress_constructor':
+            import pdb
+            pdb.set_trace()
+        # func.is_constructor will be True if we have a (constructor) annotation
+        if not func.is_constructor and \
+                not (func.symbol.find('_new_') >= 0 or \
+                        func.symbol.endswith('_new')):
             return False
         target = self._transformer.lookup_typenode(func.retval.type)
         if not (isinstance(target, ast.Class)
                 or (isinstance(target, (ast.Record, ast.Union, ast.Boxed))
                     and (target.get_type is not None or target.foreign))):
+            if func.is_constructor:
+                message.warn_node(func,
+                    '%s: Constructors must return an instance of their class'
+                    % (func.symbol, ))
             return False
 
-        split = self._split_uscored_by_type(subsymbol)
-        if split is None:
-            # TODO - need a e.g. (method) annotation
+        origin_node = self._get_constructor_class(func, subsymbol)
+        if origin_node is None:
             message.warn_node(func,
-                "Can't find matching type for constructor; symbol=%r" % (func.symbol, ))
+                "Can't find matching type for constructor; symbol=%r" \
+                % (func.symbol, ))
             return False
-        (origin_node, funcname) = split
+
         # Some sanity checks; only objects and boxeds can have ctors
         if not (isinstance(origin_node, ast.Class)
                 or (isinstance(origin_node, (ast.Record, ast.Union, ast.Boxed))
@@ -977,9 +1069,13 @@ method or constructor of some type."""
             return False
         # Verify the namespace - don't want to append to foreign namespaces!
         if origin_node.namespace != self._namespace:
+            if func.is_constructor:
+                message.warn_node(func,
+                    '%s: Constructors must belong to the same namespace as the '
+                    'class they belong to' % (func.symbol, ))
             return False
-        # If it takes the object as a first arg, it's not a constructor
-        if len(func.parameters) > 0:
+        # If it takes the object as a first arg, guess it's not a constructor
+        if not func.is_constructor and len(func.parameters) > 0:
             first_arg = self._transformer.lookup_typenode(func.parameters[0].type)
             if (first_arg is not None) and first_arg.gi_name == origin_node.gi_name:
                 return False
@@ -1010,20 +1106,15 @@ method or constructor of some type."""
                     str(origin_node.create_type()),
                     str(func.retval.type)))
                 return False
-        self._namespace.float(func)
-        func.name = funcname
-        func.is_constructor = True
-        origin_node.constructors.append(func)
-        # Constructors have default return semantics
-        if not func.retval.transfer:
-            func.retval.transfer = self._get_transfer_default_return(func, func.retval)
+
         return True
 
     def _pair_class_virtuals(self, node):
         """Look for virtual methods from the class structure."""
         if not node.glib_type_struct:
-            message.warn_node(node,
-                "Failed to find class structure for %r" % (node.name, ))
+            # https://bugzilla.gnome.org/show_bug.cgi?id=629080
+            #message.warn_node(node,
+            #    "Failed to find class structure for %r" % (node.name, ))
             return
 
         node_type = node.create_type()
