@@ -89,7 +89,7 @@ annotation_object_class_init (AnnotationObjectClass *klass)
   /**
    * AnnotationObject::list-signal:
    * @annotation: the annotation object
-   * @list: (type GLib.List) (element-type utf8): (transfer container): a list of strings
+   * @list: (type GLib.List) (element-type utf8) (transfer container): a list of strings
    *
    * This is a signal which takes a list of strings, but it's not
    * known by GObject as it's only marked as G_TYPE_POINTER
@@ -122,12 +122,12 @@ annotation_object_class_init (AnnotationObjectClass *klass)
   /**
    * AnnotationObject::attribute-signal:
    * @annotation: the annotation object
-   * @arg1: (some.annotation.foo1 val1): a value
-   * @arg2: (some.annotation.foo2 val2): another value
+   * @arg1: (attribute some.annotation.foo1 val1): a value
+   * @arg2: (attribute some.annotation.foo2 val2): another value
    *
    * This signal tests a signal with attributes.
    *
-   * Returns: (some.annotation.foo3 val3): the return value
+   * Returns: (attribute some.annotation.foo3 val3): the return value
    */
   annotation_object_signals[ATTRIBUTE_SIGNAL] =
     g_signal_new ("attribute-signal",
@@ -210,7 +210,7 @@ annotation_object_out (AnnotationObject *object, int *outarg)
  *
  * This is a test for in arguments
  *
- * @inarg: (in): (transfer none): This is an argument test
+ * @inarg: (in) (transfer none): This is an argument test
  * Return value: an int
  */
 gint
@@ -290,7 +290,7 @@ annotation_object_calleeowns (AnnotationObject *object, GObject **toown)
  *
  * This is a test for out arguments, one transferred, other not
  *
- * @toown1: (out) (transfer): a #GObject
+ * @toown1: (out) (transfer full): a #GObject
  * @toown2: (out) (transfer none): a #GObject
  * Return value: an int
  */
@@ -613,6 +613,15 @@ annotation_object_watch_full (AnnotationObject *object,
 {
 }
 
+/**
+ * annotation_object_hidden_self:
+ * @object: (type AnnotationObject): A #AnnotationObject
+ **/
+void
+annotation_object_hidden_self (gpointer object)
+{
+}
+
 /**
  * annotation_init:
  * @argc: (inout): The number of args. 
@@ -734,9 +743,9 @@ annotation_ptr_array (GPtrArray *array)
 /**
  * annotation_attribute_func:
  * @object: A #AnnotationObject.
- * @data: (some.annotation value) (another.annotation blahvalue): Some data.
+ * @data: (attribute some.annotation value) (attribute another.annotation blahvalue): Some data.
  *
- * Returns: (some.other.annotation value2) (yet.another.annotation another_value): The return value.
+ * Returns: (attribute some.other.annotation value2) (attribute yet.another.annotation another_value): The return value.
  */
 gint
 annotation_attribute_func (AnnotationObject *object,
@@ -757,3 +766,28 @@ annotation_invalid_annotation (int foo)
 
 
 char backslash_parsing_tester_2 = '\\';
+
+
+/**
+ * annotation_test_parsing_bug630862:
+ *
+ * See https://bugzilla.gnome.org/show_bug.cgi?id=630862
+ *
+ * Returns: (transfer none): An object, note the colon:in here
+ */
+GObject  *
+annotation_test_parsing_bug630862 (void)
+{
+  return NULL;
+}
+
+
+/** 
+ * annotation_space_after_comment_bug631690:
+ *
+ * Explicitly test having a space after the ** here.
+ */
+void
+annotation_space_after_comment_bug631690 (void)
+{
+}
