@@ -1919,6 +1919,16 @@ regress_test_obj_new (RegressTestObj *obj)
   return g_object_new (REGRESS_TEST_TYPE_OBJ, NULL);
 }
 
+/**
+ * regress_constructor: (constructor)
+ *
+ */
+RegressTestObj *
+regress_constructor (void)
+{
+  return g_object_new (REGRESS_TEST_TYPE_OBJ, NULL);
+}
+
 /**
  * regress_test_obj_new_from_file:
  */
